@@ -5,7 +5,7 @@ from enum import Enum
 from random import choice
 
 import typer
-from psycopg import connect
+from psycopg import connect, conninfo
 from pymongo import MongoClient
 from rich.console import Console
 
@@ -82,11 +82,11 @@ def validate_local(
 @app.command()
 def validate_lims(
     db_address: str,
-    lims_address: str,  # postgres://limsreader:limsro2@limsdb2:5432/lims2
+    lims_address: str,
     lims_id: str,
 ) -> None:
     client = MongoClient(db_address)
-    conn = connect(**psycopg.conninfo.conninfo_to_dict(lims_address))
+    conn = connect(**conninfo.conninfo_to_dict(lims_address))
     with conn.cursor() as cursor:
         validated = validate_lims_upload(
             client,
